@@ -10,15 +10,10 @@ use warnings;
 use Class::Throwable;
 use Tree::Simple::Visitor::FindByPath;
 use Tree::Simple::Visitor::GetAllDescendents;
+use Carp qw/croak/;
 
 BEGIN { __PACKAGE__->mk_accessors(qw/app actions/) }
 
-=todo
-
-	* external uris -> private paths
-
-=cut
-
 our $DENIED  = bless {}, __PACKAGE__ . "::Denied";
 our $ALLOWED = bless {}, __PACKAGE__ . "::Allowed";
 
@@ -68,7 +63,16 @@ sub fudge_condition {
     my ( $self, $condition ) = @_;
 
     # make almost anything into a code ref/method name
-    if ( my $reftype = ref $condition ) {
+
+    if (!defined($condition)
+        # no warnings
+        or $condition eq '1'
+        or $condition eq '0'
+        or $condition eq "" )
+    {
+        return sub { $condition };
+    }
+    elsif ( my $reftype = ref $condition ) {
         $reftype eq "CODE" and return $condition;
 
         # if it's not a code ref and it's a ref, we only know
@@ -87,13 +91,13 @@ sub fudge_condition {
             $c->check_user_roles(@$condition);
         };
     }
-    else {
-        $self->app->can($condition)
-          or die "Can't use string '$condition' as an ACL "
-          . "condition unless \$c->can('$condition').";
-
+    elsif ( $self->app->can($condition) ) {
         return $condition;    # just a method name
     }
+    else {
+        croak "Can't use '$condition' as an ACL "
+          . "condition unless \$c->can('$condition').";
+    }
 }
 
 sub add_rule {
@@ -254,11 +258,53 @@ checks for L<Catalyst::Plugin::Authorization::ACL>.
 
 	# internal
 
+=head1 METHODS
+
+=over 4
+
+=item new $app
+
+Create a new rule engine for $app
+
+=item add_allow $cond
+
+=item add_deny $cond
+
+fudge C<$cond>, make cond into a rule, and C<add_rule>
+
+=item add_rule $path, $rule
+
+Add rule to all actions under $path
+
+=item append_rule_to_action $action, $index, $rule, $cxt
+
+Append C<$rule> to C<$action> in slot C<$index>, and store context info C<$cxt>
+for error reporting.
+
+=item check_action_rules $action
+
+Evaluate the rules for an action
+
+=item fudge_condition $thingy
+
+Converts a C<$thingy> into a subref, for DWIM goodness. See the main ACL docs.
+
+=item get_action_data $action
+
+=item get_cxt_for_rule $rule
+
+=item get_rules
+
+=back
+
 =head1 DESCRIPTION
 
 This is the engine which executes the access control checks for
 L<Catalyst::Plugin::Authorization::ACL>. Please use that module directly.
 
+=head1 TODO
+
+    * external uris -> private paths
+
 =cut
 
-
